@@ -10,6 +10,9 @@ from .command import Command
 from .utils import prettydate
 from .socketclient import SocketClient
 
+import logging
+log = logging.getLogger(__name__)
+
 class DockerCommand(Command):
     """
     Run commands against the Orchard public Docker cloud.
@@ -191,7 +194,7 @@ class DockerCommand(Command):
             -e VAR=VAL  Set an environment variable (can be used multiple times)
             -p PORT     Expose a container's port to the host
         """
-        print "Pulling image %s" % options['IMAGE']
+        log.info("Pulling image %s", options['IMAGE'])
 
         new_container = self.docker.replace_container(
             options['CONTAINER'],
@@ -266,9 +269,10 @@ class DockerCommand(Command):
             -i          Attach this terminal's stdin to the running process
             -m BYTES    Amount of memory, rounded to nearest Orchard container size
                         (in bytes with SI suffix) [default: 512M]
-            -p PORT     Expose a container's port to the host. In the format 
+            -p PORT     Expose a container's port to the host. In the format
                         public:private. If the public port is omitted, a random
                         port will be assigned.
+            --privileged  Give extended privileges to this container
             -t          Allocate a pseudo-tty
             -v PATH     Mount a volume at the specified path (e.g. /var/lib/mysql)
         """
@@ -288,7 +292,7 @@ class DockerCommand(Command):
             volumes = {path:{}}
 
         if options['IMAGE'] != 'ubuntu':
-            print "Pulling image %s" % options['IMAGE']
+            log.info("Pulling image %s", options['IMAGE'])
 
         # Memory limit
         mem_limit = None
@@ -314,6 +318,7 @@ class DockerCommand(Command):
             tty=options['-t'],
             environment=options['-e'],
             ports=ports,
+            privileged=options['--privileged'],
             volumes=volumes,
             mem_limit=mem_limit
         )
@@ -394,11 +399,23 @@ class DockerCommand(Command):
         print "Go version:", docker_version["GoVersion"]
 
     def _attach_to_container(self, container_id, interactive, logs=False, stream=True, raw=False):
-        socket = self.docker.attach_socket(
+        stdio = self.docker.attach_socket(
             container_id,
             params={
                 'stdin': 1 if interactive else 0,
                 'stdout': 1,
+                'stderr': 0,
+                'logs': 1 if logs else 0,
+                'stream': 1 if stream else 0
+            },
+            ws=True,
+        )
+
+        stderr = self.docker.attach_socket(
+            container_id,
+            params={
+                'stdin': 0,
+                'stdout': 0,
                 'stderr': 1,
                 'logs': 1 if logs else 0,
                 'stream': 1 if stream else 0
@@ -406,9 +423,12 @@ class DockerCommand(Command):
             ws=True,
         )
 
-        keep_running = lambda: self.docker.inspect_container(container_id)['State']['Running']
-
-        return SocketClient(socket, interactive=interactive, raw=raw, keep_running=keep_running)
+        return SocketClient(
+            socket_in=stdio,
+            socket_out=stdio,
+            socket_err=stderr,
+            raw=raw,
+        )
 
 
 def catch_api_error(fn, success_message=None):
